@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+import sys
 from sqlalchemy import types
 from sqlalchemy.dialects.postgresql import BIT
 import six
@@ -12,6 +13,13 @@ from ..compat import total_ordering
 from ..exceptions import ImproperlyConfigured
 
 
+def call_unbound(func, *args, **kwargs):
+    try:
+        return six.get_unbound_function(func)(*args, **kwargs)
+    except AttributeError:
+        return func(*args, **kwargs)
+
+
 @total_ordering
 class WeekDay(object):
     NUM_WEEK_DAYS = 7
@@ -57,7 +65,7 @@ class WeekDay(object):
         names = get_day_names(
             width,
             context,
-            self.get_locale()
+            call_unbound(self.get_locale)
         )
         return names[self.index]
 
@@ -69,7 +77,7 @@ class WeekDay(object):
     def position(self):
         return (
             self.index -
-            self.get_locale().first_week_day
+            call_unbound(self.get_locale).first_week_day
         ) % self.NUM_WEEK_DAYS
 
 
@@ -118,8 +126,12 @@ class WeekDays(object):
             self.as_bit_string()
         )
 
-    def __str__(self):
-        return six.text_type(self).encode('utf-8')
+    if sys.version_info[0] >= 3:  # Python 3
+        def __str__(self):
+            return self.__unicode__()
+    else:  # Python 2
+        def __str__(self):
+            return self.__unicode__().encode('utf8')
 
     def __unicode__(self):
         return u', '.join(six.text_type(day) for day in self)
@@ -127,7 +139,7 @@ class WeekDays(object):
     def as_bit_string(self):
         return ''.join(
             '1' if WeekDay(index) in self._days else '0'
-            for index in xrange(WeekDay.NUM_WEEK_DAYS)
+            for index in six.moves.xrange(WeekDay.NUM_WEEK_DAYS)
         )
 
 
